print("import: 'lxml'")
import lxml

print("import: 'lxml.etree'")
import lxml.etree

print("import: 'lxml.objectify'")
import lxml.objectify

print("import: 'lxml.includes'")
import lxml.includes

print("import: 'lxml.html'")
import lxml.html

print("import: 'lxml.isoschematron'")
import lxml.isoschematron

